@@ -6,7 +6,9 @@
 
 Time::Decimal -- Handle french revolutionary ten hour days
 
-L<Esperanto|POD2::EO::Time::Decimal>
+L<I<Esperanto priskribo>|POD2::EO::Time::Decimal>
+
+
 
 =head1 SYNOPSIS
 
@@ -35,26 +37,16 @@ or
     ln <path>/Time/Decimal.pm dectime
     dectime [-option ...] [time ...]
 
+
+
 =head1 DESCRIPTION
 
 The Babyloninan 24 hour clock is one of the last complicated vestiges of the
 pre-decimal age.  The french revolution, when it created decimal measures for
 everything, also invented a division of the day into ten hours of 100 minutes
-and again 100 seconds each.  The advantage is that seconds and minutes are
-roughly as long as those we know.  Hours are of course more than twice as long.
-
-La babilona 24-hora horloĝo estas unu de la lastaj komplikaj restaĵoj de la
-antaŭ-dekuma epoko.  La franca revolucio, kiam ĝi kreis dekumajn mezurojn por
-ĉio, ankaŭ inventis disdividon de la tago en dek horojn, ĉiuj je 100 minutoj
-kaj tiuj de 100 sekundoj.  La avantaĝo estas ke sekundoj kaj minutoj daŭras
-proksimume same kiel tiuj kiujn ni konas.  Horoj kompreneble daŭras pli ol
-duoble.
-
-Por povi memstare rekoni dekuman tempon, ni uzas C<_> anstataŭ C<:> kiel
-separilo.  Tiu signo uzeblas en multe pli da komputilaj kuntekstoj.  En Perl
-ĝi estas ebla separilo inter ciferoj.  Kaj pri tio ja temas ĉi tie, ĉar dekuma
-tempo H_MM estas nenio alia ol tri-cifera nombro da minutoj.  Samo direblas
-pri kvin-cifera nombro da sekundoj
+and again 100 seconds each.  The nice thing is that seconds and (to a lesser
+degree) minutes are roughly as long as those we know.  Hours are of course
+more than twice as long.
 
 So as to be able to automatically recognize decimal time, we use C<_> instead
 of C<:> as a separator.  This character is usable in many more computer
@@ -62,6 +54,10 @@ contexts.  In Perl it is a possible separator between digits.  And that's what
 it means here, because a decimal time H_MM is nothing else than a three digit
 number of minutes.  The same applies to five digit numbers of seconds.
 
+For the purpose of transformation it doesn't matter whether we see 1:30 as an
+early morning time, or as a duration of one and a half hours.  Thus a time
+like 84:00 or 35_00 meaning three and a half days is allowed.
+
 =cut
 
 package Time::Decimal;
@@ -69,7 +65,7 @@ package Time::Decimal;
 use warnings;
 use strict;
 
-our $VERSION = 0.03;
+our $VERSION = 0.07;
 
 sub FACTOR() { .86400 }		# One day has 86400 babylonian seconds.
 
@@ -78,20 +74,18 @@ sub FACTOR() { .86400 }		# One day has 86400 babylonian seconds.
 Nothing is exported by default, but all of the following may be imported by
 the C<use> statement:
 
-Nenio estas memstare elportita, sed vi povas enporti la sekvajn per la C<use>
-ordono:
-
 =over
 
 =item $precision
 
-    's'	seconds
+    ''		minutes (the default)
+    's'		seconds
     'ds'	deciseconds
     'cs'	centiseconds
     'ms'	milliseconds
     'µs', 'us'	microseconds
 
-UTF-8, Latin-1, -3, -5, -7 or Latin-9
+Where the µ-sign may be in UTF-8, Latin-1, -3, -5, -7 or Latin-9.
 
 =cut
 
@@ -108,7 +102,7 @@ our $precision = '';
 		 ms %.3f
 		 µs %f
 		 us %f);
-    $fmt{"\xb5s"} = '%f';	# Latin µ
+    $fmt{"\xb5s"} = '%f';	# Latin-[13579] µ
     sub _seconds(\$$$) {
 	my( $minref, $modulo, $sec ) = @_;
 	if( $precision ) {
@@ -172,34 +166,41 @@ sub h10_h24(@) {
 }
 
 
-# Perl is fussy about what strings it accepts as a number
-sub h10_h10s($) {
+# Perl is fussy about what strings it accepts as a number.  We allow both
+# leading zeroes(not as octal) and underscores, which Perl's @#!% string to
+# number automatism refuses to accept, unlike in literal numbers.
+sub _cleanup($) {
     if ( $_[0] ) {
 	for ( my $copy = $_[0] ) {
 	    tr/_//d;
 	    s/^0+(?=.)//;
-	    return $_;
+	    return $_ + 0;
 	}
     } else {
-	0;
+	'00';
     }
 }
 
+my $h10re = qr/^(\d+) _ (\d\d) (?: _ (\d\d (?: \.\d+_?\d* )?) )?$/x;
 sub transform($) {
     if( $_[0] =~ /^(\d+) : ([0-5]\d) (?: : ([0-5]\d (?: \.\d+_?\d* )?) )? \s*(?:(am)|(pm))? $/ix ) {
-	h24_h10 $4 ? $1 % 12 : $5 ? $1 % 12 + 12 : $1, $2, h10_h10s $3;
-				# Abuse h10_h10s, as it can also cleanup h24s
-    } elsif( $_[0] =~ /^(\d) _ (\d\d) (?: _ (\d\d (?: \.\d+_?\d* )?) )?$/x ) {
-	h10_h24 $1, $2, h10_h10s $3;
+	h24_h10 $4 ? $1 % 12 : $5 ? $1 % 12 + 12 : $1, $2, _cleanup $3;
+    } elsif( $_[0] =~ /$h10re/o ) {
+	h10_h24 $1, $2, _cleanup $3;
     } else {
 	die "$0: invalid time format `$_[0]'\n";
     }
 }
 
+sub h10_h10s($) {
+    $_[0] =~ /$h10re/o;
+    0 + ($1 . $2 . _cleanup $3);
+}
+
 sub difference(@) {
     my $acc;
     for( @_ ) {
-	my $sec = h10_h10s( /:/ ? transform $_ : transform transform $_ );
+	my $sec = h10_h10s( /:/ ? transform $_ : $_ );
 	if( defined $acc ) {
 	    $acc -= $sec;
 	} else {
@@ -212,7 +213,7 @@ sub difference(@) {
 sub sum(@) {
     my $acc = 0;
     for( @_ ) {
-	$acc += h10_h10s( /:/ ? transform $_ : transform transform $_ );
+	$acc += h10_h10s( /:/ ? transform $_ : $_ );
     }
     h10s_h10 $acc;
 }
@@ -227,41 +228,50 @@ sub now_h10(;$) {
     h24_h10 $h, $min, $sec + $usec;
 }
 
-{
-    my %delta = ('' => 100,
-		 s => 1,
-		 ds => .1,
-		 cs => .01,
-		 ms => .001,
-		 'µs' => .000_001,
-		 us => .000_001);
-    $delta{"\xb5s"} = .000_001;	# Latin µ
-    sub loop(&) {
-	my $callback = $_[0];
-	require Time::HiRes;
-	my $last = '';
-	while( 1 ) {
-	  TOO_EARLY:
-	    my( $usec, $sec, $min, $h ) = Time::HiRes::time();
-	    my $orig = $usec;
-	    $sec = int $usec;
-	    $usec -= $sec;
-	    ($sec, $min, $h) = localtime $sec;
-	    $sec = $h * 3600 + $min * 60 + $sec + $usec;
-	    my $cur = h24s_h10( $sec );
-	    goto TOO_EARLY if $cur eq $last; # Rarely select sleeps a bit too short, how about T::HR::sleep?
-	    &$callback( $cur );
-	    $last = $cur;
-	    $sec = ($sec / FACTOR + $delta{$precision}) / $delta{$precision};
-	    $sec = $orig - Time::HiRes::time() + # Compensate callback time
-		(1 - $sec + int $sec) * $delta{$precision} * FACTOR;
-	    Time::HiRes::sleep( $sec ) if $sec > 0;
-	}
+=item loop { I<perlcode> }
+
+
+
+=cut
+
+my %delta = ('' => 100,
+	     s => 1,
+	     ds => .1,
+	     cs => .01,
+	     ms => .001,
+	     'µs' => .000_001,
+	     us => .000_001,
+	     "\xb5s" => .000_001);	# Latin-[13579] µ
+sub loop(&) {
+    my $callback = $_[0];
+    require Time::HiRes;
+    my $last = '';
+    while( 1 ) {
+	my( $usec, $sec, $min, $h ) = Time::HiRes::time();
+	my $orig = $usec;
+	$sec = int $usec;
+	$usec -= $sec;
+	($sec, $min, $h) = localtime $sec;
+	$sec = $h * 3600 + $min * 60 + $sec + $usec;
+	my $cur = h24s_h10( $sec );
+	redo if $cur eq $last; # Rarely select sleeps a bit too short, how about T::HR::sleep?
+	last if !&$callback( $cur );
+	$last = $cur;
+	$sec = ($sec / FACTOR + $delta{$precision}) / $delta{$precision};
+	$sec = $orig + (1 - $sec + int $sec) * $delta{$precision} * FACTOR -
+	    Time::HiRes::time(); # Compensate callback time and our overhead
+	Time::HiRes::sleep( $sec ) if $sec > 0; # Callback may have taken longer than 1 unit
     }
 }
 
+=item See SYNOPSIS above
+
+I<Documentation for the various functions remains to be written.>
+
 =back
 
+
+
 =head2 Command Line Interface
 
 =over
@@ -278,53 +288,44 @@ sub now_h10(;$) {
 
 Output times at the given precision, instead of minutes.
 
-Eligu tempojn je la donita precizeco, anstataŭ minutoj.
-
 
 =item -e, --echo
 
 Output the transformed time along with the transformation.
 
-Eligu la transformitan tempon kune kun la transformaĵo.
 
 =item -r, --reverse
 
 Retransform the transformation to see possible loss due to insufficient
 precision.
 
-Retransformu la transformaĵon por vidi eblan perdon pro manko de precizeco.
 
 =item -l, --loop
 
 Output the time again each time the result changes at the wanted precision.
 Can be used as a clock, but if the precision is too small, the terminal
-emulation may have problems, either flickering or stalling.
-
-Eligu la tempon denove ĉiufoje ke la rezulto ŝanĝiĝas je la dezirita
-precizeco.  Uzeblas kiel horloĝo, sed se la precizeco tro malgrandas, la
-montrila programo povas havi problemojn, aŭ ŝanceliĝante, aŭ rifuzante.
+emulation may have problems, either flickering or repeatedly stalling (C<rxvt>
+family).
 
 
 =item -o, --old, --old-table, --babylonian, --babylonian-table
 
 =item -n, --new, --new-table, --decimal, --decimal-table
 
-Supplies about 70 times of common interest.  Implies C<--echo>.
-
-Provizas ĉirkaŭ 70 tempoj de komuna intereso.  Implicas C<--echo>.
+Supplies overviews of about 70 times of common interest each.  Implies
+C<--echo>.
 
 =back
 
 =cut
 
 if( caller ) {
-      require Exporter;
-      our @ISA = 'Exporter';
-      our @EXPORT_OK = qw($precision h24s_h10 h24_h10 h10s_h24 h10_h24
-			  transform now_h10 loop);
+    use Exporter 'import';
+    our @EXPORT_OK = qw($precision h24s_h10 h24_h10 h10s_h24 h10_h24
+			transform now_h10 loop);
 } else {
     require Getopt::Long;
-    Getopt::Long::config( qw(bundling no_getopt_compat) );
+    Getopt::Long::config( qw(bundling no_getopt_compat require_order) );
 
     my( $echo, $reverse, $loop );
     Getopt::Long::GetOptions
@@ -371,7 +372,8 @@ __END__
 
 L<DateTime::Calendar::FrenchRevolutionary> fits nicely into the DateTime
 hierarchy.  Alas that doesn't handle fractions, so they have a lossy
-transformation.  Besides fractions are much more natural in decimal time.
+transformation.  Besides fractions seem even more natural in decimal time.
+
 
 =head1 AUTHOR
 
